@@ -15,6 +15,7 @@
 #include <ZenLib/ZtringList.h>
 #include "MediaConchLib.h"
 #include "Core.h"
+#include "Reports.h"
 #include "DaemonClient.h"
 #include "Policy.h"
 #include "Http.h"
@@ -24,6 +25,7 @@
 #include "generated/PolicySample5.h"
 #include "generated/PolicySample6.h"
 #include "generated/PolicySample7.h"
+#include "generated/PolicySample8.h"
 
 namespace MediaConch {
 
@@ -131,6 +133,19 @@ int MediaConchLib::test_mil_option(const std::string& key, std::string& value, s
     return 0;
 }
 
+//---------------------------------------------------------------------------
+bool MediaConchLib::mil_has_curl_enabled()
+{
+    String Result = core->Menu_Option_Preferences_Option(__T("info_canhandleurls"), __T(""));
+    if (Result.empty())
+        return false;
+
+    if (Result == __T("1"))
+        return true;
+
+    return false;
+}
+
 //---------------------------------------------------------------------------
 bool MediaConchLib::ReportAndFormatCombination_IsValid(const std::vector<std::string>&,
                                                        const std::bitset<MediaConchLib::report_Max>& reports,
@@ -143,13 +158,9 @@ bool MediaConchLib::ReportAndFormatCombination_IsValid(const std::vector<std::st
         return false;
     }
 
-    // Forcing some formats
-    if (Format == MediaConchLib::format_Text && !display.empty())
-        Format = format_Xml; //Forcing Text (default) to XML
-
-    if (Format != MediaConchLib::format_Xml && !display.empty())
+    if (Format != MediaConchLib::format_Max && !display.empty())
     {
-        reason = "If a display is used, no other output format can be used";
+        reason = "If a display is used, no other output format can be used.";
         return false;
     }
 
@@ -349,27 +360,17 @@ int MediaConchLib::checker_file_information(int user, long id, MediaConchLib::Ch
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-int MediaConchLib::checker_get_report(int user, const std::bitset<report_Max>& report_set, format f,
-                                      const std::vector<long>& files,
-                                      const std::vector<size_t>& policies_ids,
-                                      const std::vector<std::string>& policies_contents,
-                                      const std::map<std::string, std::string>& options,
-                                      Checker_ReportRes* result, std::string& error,
-                                      const std::string* display_name,
-                                      const std::string* display_content)
+int MediaConchLib::checker_get_report(CheckerReport& c_report, Checker_ReportRes* result, std::string& error)
 {
-    if (!files.size())
-        return errorHttp_INVALID_DATA;
+    if (!c_report.files.size())
+    {
+        error = "No file given for report.";
+        return -1;
+    }
 
     if (use_daemon)
-        return daemon_client->checker_get_report(user, report_set, f, files,
-                                                 policies_ids, policies_contents,
-                                                 options, result, error,
-                                                 display_name, display_content);
-    return core->checker_get_report(user, report_set, f, files,
-                                    policies_ids, policies_contents,
-                                    options, result, error,
-                                    display_name, display_content);
+        return daemon_client->checker_get_report(c_report, result, error);
+    return core->reports.checker_get_report(c_report, result, error);
 }
 
 //---------------------------------------------------------------------------
@@ -392,10 +393,10 @@ int MediaConchLib::checker_validate(int user, report report, const std::vector<l
                                                options,
                                                result, error);
 
-    return core->checker_validate(user, report, files,
-                                  policies_ids, policies_contents,
-                                  options,
-                                  result, error);
+    return core->reports.checker_validate(user, report, files,
+                                          policies_ids, policies_contents,
+                                          options,
+                                          result, error);
 }
 
 //---------------------------------------------------------------------------
@@ -719,24 +720,6 @@ const std::string& MediaConchLib::get_implementation_verbosity()
     return core->get_implementation_verbosity();
 }
 
-//***************************************************************************
-// XSL Transformation
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-int MediaConchLib::transform_with_xslt_file(const std::string& report, const std::string& file,
-                                            const std::map<std::string, std::string>& opts, std::string& result)
-{
-    return core->transform_with_xslt_file(report, file, opts, result);
-}
-
-//---------------------------------------------------------------------------
-int MediaConchLib::transform_with_xslt_memory(const std::string& report, const std::string& memory,
-                                              const std::map<std::string, std::string>& opts, std::string& result)
-{
-    return core->transform_with_xslt_memory(report, memory, opts, result);
-}
-
 //***************************************************************************
 // Configuration
 //***************************************************************************
@@ -848,6 +831,10 @@ int MediaConchLib::load_system_policy()
     memory = std::string(policy_sample_7);
     core->policies.import_policy_from_memory(-1, memory, err, path.c_str(), true);
 
+    policy_path = path + "policy_sample_8.xml";
+    memory = std::string(policy_sample_8);
+    core->policies.import_policy_from_memory(-1, memory, err, path.c_str(), true);
+
     return 0;
 }
 
@@ -888,4 +875,10 @@ int MediaConchLib::load_existing_policy()
     return 0;
 }
 
+//---------------------------------------------------------------------------
+void MediaConchLib::register_log_callback(void (*log)(struct MediaInfo_Event_Log_0* Event))
+{
+    core->ecb.log = log;
+}
+
 }
