@@ -56,18 +56,26 @@ protected:
     void         charge_local_dir(const QString& directory, QStringList& tmp);
     QString      choose_file_settings();
     QString      choose_file_import_policy();
+    QString      choose_file_policy_from_file();
     void         string_to_json(QString& str);
 
 private Q_SLOTS:
     void         timer_menu_link();
 
 public Q_SLOTS:
+    void         on_file_selected(const QString& filename, const QString& path,
+                                  const QString& policy, const QString& display, const QString& verbosity,
+                                  bool fixer, QString& ret, std::string& err_str);
+    void         on_file_selected_end(const std::string& err_str, QString& ret);
+    void         on_file_selected_formValues(const FileRegistered* fr, QString& formValues);
     QString      on_file_upload_selected(const QString& policy, const QString& display, const QString& verbosity,
                                          bool fixer);
     QString      on_file_online_selected(const QString& url, const QString& policy, const QString& display,
                                          const QString& verbosity, bool fixer);
     QString      on_file_repository_selected(const QString& policy, const QString& display,
                                              const QString& verbosity, bool fixer);
+    QString      on_file_from_db_selected();
+    QString      status_reports_multi(const QStringList& ids, const QStringList& policy_ids);
     void         on_save_settings_selected(const QString& policy, const QString& display, const QString& verbosity,
                                            const QString& save_report, const QString& load_files,
                                            const QString& save_policy, const QString& load_policy,
@@ -86,9 +94,10 @@ public Q_SLOTS:
     QString      on_fill_mediatrace_report(long file_id);
     void         on_save_mediatrace_report(long file_id);
     QString      on_create_policy_from_file(long file_id);
+    QString      checker_force_analyze(long id);
 
     void         close_all();
-    void         close_element(const QString& file);
+    void         close_element(long file_id);
 
     bool         report_is_html(const QString& report);
     bool         report_is_xml(const QString& report);
@@ -103,7 +112,6 @@ public Q_SLOTS:
     QString      file_is_analyzed(const QStringList& ids);
     void         change_policy_for_file(long file_id, const QString& policy);
 
-
     QString      display_add_file(const QString& name);
     void         display_export_id(const QString& name);
     void         display_delete_id(const QString& name);
@@ -115,6 +123,7 @@ public Q_SLOTS:
     QString      import_policy();
     QString      import_policy(const QString& file);
     int          import_policy(const QStringList& files);
+    QString      policy_from_file();
     QString      policy_import_data(const QString& data);
     QString      xslt_policy_create(int parent_id);
     QString      policy_duplicate(int id, int dst_policy_id);
