@@ -129,7 +129,7 @@ std::string WorkerFiles::get_filename_from_registered_file_id(long file_id)
 }
 
 //---------------------------------------------------------------------------
-void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered>& files)
+void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered*>& files)
 {
     working_files_mutex.lock();
     std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
@@ -138,7 +138,7 @@ void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered>& fi
         if (!it->second)
             continue;
 
-        files[it->first] = FileRegistered(*it->second);
+        files[it->first] = new FileRegistered(*it->second);
     }
     working_files_mutex.unlock();
 }
@@ -146,11 +146,16 @@ void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered>& fi
 //---------------------------------------------------------------------------
 int WorkerFiles::add_file_to_list(const std::string& file, const std::string& path,
                                   int policy, int display, int verbosity, bool fixer,
-                                  std::string& err)
+                                  bool force, bool create_policy, std::string& err)
 {
     std::string full_file(path);
-    if (path.length())
+#ifdef WINDOWS
+    if (full_file.size() && full_file[full_file.size() - 1] != '/' && full_file[full_file.size() - 1] != '\\')
         full_file += "/";
+#else
+    if (full_file.length())
+        full_file += "/";
+#endif
     full_file += file;
 
     bool exists = false;
@@ -160,7 +165,8 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     {
         exists = true;
         // nothing to do
-        if (!fixer && policy == working_files[full_file]->policy && display == working_files[full_file]->display
+        if (!force && !create_policy &&
+            policy == working_files[full_file]->policy && display == working_files[full_file]->display
             && verbosity == working_files[full_file]->verbosity)
         {
             working_files_mutex.unlock();
@@ -168,6 +174,8 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
         }
         else
             fr = new FileRegistered;
+        if (!force)
+            fr->analyzed = working_files[full_file]->analyzed;
     }
     else
         fr = new FileRegistered;
@@ -187,6 +195,7 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     fr->policy = policy;
     fr->display = display;
     fr->verbosity = verbosity;
+    fr->create_policy = create_policy;
 
     working_files_mutex.lock();
 
@@ -199,7 +208,7 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     unfinished_files.push_back(full_file);
     unfinished_files_mutex.unlock();
 
-    if (!fixer && exists)
+    if (!force && exists)
     {
         to_update_files_mutex.lock();
         to_update_files[full_file] = new FileRegistered(*fr);
@@ -212,7 +221,7 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
 
     int ret;
     std::vector<long> files_id;
-    if ((ret = mainwindow->analyze(vec, fixer, files_id, err)) < 0)
+    if ((ret = mainwindow->analyze(vec, fixer, force, files_id, err)) < 0)
     {
         mainwindow->set_str_msg_to_status_bar(err);
         return -1;
@@ -237,6 +246,92 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int WorkerFiles::add_attachment_to_list(const std::string& file, int policy, int display,
+                                        int verbosity, std::string& err)
+{
+    bool exists = false;
+    FileRegistered *fr = NULL;
+    working_files_mutex.lock();
+    if (working_files.find(file) != working_files.end() && working_files[file])
+    {
+        exists = true;
+        // nothing to do
+        if (policy == working_files[file]->policy && display == working_files[file]->display
+            && verbosity == working_files[file]->verbosity)
+        {
+            working_files_mutex.unlock();
+            return 0;
+        }
+        else
+            fr = new FileRegistered;
+        fr->analyzed = working_files[file]->analyzed;
+    }
+    else
+        fr = new FileRegistered;
+    working_files_mutex.unlock();
+
+    // Keep the old index for the same file
+    if (exists)
+    {
+        fr->index = working_files[file]->index;
+        fr->file_id = working_files[file]->file_id;
+    }
+    else
+        fr->index = file_index++;
+
+    fr->filename = file;
+    fr->filepath = "";
+    fr->policy = policy;
+    fr->display = display;
+    fr->verbosity = verbosity;
+    fr->create_policy = false;
+
+    working_files_mutex.lock();
+
+    if (exists)
+        delete working_files[file];
+    working_files[file] = fr;
+    working_files_mutex.unlock();
+
+    unfinished_files_mutex.lock();
+    unfinished_files.push_back(file);
+    unfinished_files_mutex.unlock();
+
+    if (exists)
+    {
+        to_update_files_mutex.lock();
+        to_update_files[file] = new FileRegistered(*fr);
+        to_update_files_mutex.unlock();
+        return 0;
+    }
+
+    std::vector<std::string> vec;
+    vec.push_back(file);
+
+    int ret;
+    std::vector<long> files_id;
+    if ((ret = mainwindow->analyze(vec, false, false, files_id, err)) < 0)
+    {
+        mainwindow->set_str_msg_to_status_bar(err);
+        return -1;
+    }
+
+    if (files_id.size() != 1)
+    {
+        err = "Internal error: analyze result is not correct, no id returned.";
+        return -1;
+    }
+
+    fr->file_id = files_id[0];
+
+    working_files_mutex.lock();
+    working_files[file]->file_id = files_id[0];
+    working_files_mutex.unlock();
+
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 void WorkerFiles::update_policy_of_file_registered_from_file(long file_id, int policy)
 {
@@ -365,7 +460,14 @@ void WorkerFiles::update_update_files_registered()
     {
         std::map<std::string, FileRegistered*>::iterator it = to_update_files.begin();
         for (; it != to_update_files.end(); ++it)
+        {
+            if (!it->second)
+                continue;
+
             vec.push_back(it->second);
+            if (it->second->create_policy)
+                mainwindow->create_policy_from_file(it->second);
+        }
         to_update_files.clear();
     }
     to_update_files_mutex.unlock();
@@ -437,6 +539,9 @@ void WorkerFiles::update_unfinished_files()
             if (st_res.tool)
                 fr->report_kind = *st_res.tool;
 
+            for (size_t x = 0; x < st_res.generated_id.size(); ++x)
+                fr->generated_id.push_back(st_res.generated_id[x]);
+
             std::vector<size_t> policies_ids;
             std::vector<std::string> policies_contents;
             std::map<std::string, std::string> options;
@@ -523,22 +628,31 @@ void WorkerFiles::update_unfinished_files()
 }
 
 //---------------------------------------------------------------------------
-void WorkerFiles::remove_file_registered_from_file(const std::string& file)
+void WorkerFiles::remove_file_registered_from_id(long file_id)
 {
+    std::string file;
+    FileRegistered *fr = NULL;
     working_files_mutex.lock();
-    std::map<std::string, FileRegistered*>::iterator it = working_files.find(file);
-    if (it == working_files.end() || !working_files[file])
+    std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
+    for (; it != working_files.end(); ++it)
     {
-        working_files_mutex.unlock();
-        return;
+        if (!it->second)
+            continue;
+
+        if (it->second->file_id == file_id)
+        {
+            fr = it->second;
+            file = it->first;
+            it->second = NULL;
+            working_files.erase(it);
+            break;
+        }
     }
-
-    FileRegistered* fr = working_files[file];
-
-    working_files[file] = NULL;
-    working_files.erase(it);
     working_files_mutex.unlock();
 
+    if (!fr)
+        return;
+
     to_delete_files_mutex.lock();
     to_delete_files[file] = fr;
     to_delete_files_mutex.unlock();
@@ -642,8 +756,13 @@ void WorkerFiles::fill_registered_files_from_db()
         FileRegistered *fr = vec[i];
 
         std::string full_file(fr->filepath);
+#ifdef WINDOWS
+        if (full_file.size() && full_file[full_file.size() - 1] != '/' && full_file[full_file.size() - 1] != '\\')
+            full_file += "/";
+#else
         if (full_file.length())
             full_file += "/";
+#endif
         full_file += fr->filename;
 
         //check if policy still exists
@@ -666,7 +785,7 @@ void WorkerFiles::fill_registered_files_from_db()
 
         int ret;
         std::vector<long> files_id;
-        if ((ret = mainwindow->analyze(tmp, false, files_id, err2)) < 0)
+        if ((ret = mainwindow->analyze(tmp, false, false, files_id, err2)) < 0)
             mainwindow->set_str_msg_to_status_bar(err2);
         else if (!files_id.size())
             mainwindow->set_str_msg_to_status_bar("Internal error: Analyze result is not correct.");
